@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.21';
+$VERSION = '0.22';
 
 #----------------------------------------------------------------------------
 
@@ -65,7 +65,7 @@ A test module to validate a CPAN META.yml file.
 #----------------------------------------------------------------------------
 
 #############################################################################
-#Library Modules															#
+#Library Modules                                                            #
 #############################################################################
 
 use Parse::CPAN::Meta;
@@ -88,7 +88,7 @@ sub import {
 }
 
 #############################################################################
-#Interface Functions														#
+#Interface Functions                                                        #
 #############################################################################
 
 =head1 FUNCTIONS
@@ -121,7 +121,7 @@ parsed.
 =cut
 
 sub meta_spec_ok {
-	my ($file, $vers, $msg) = @_;
+    my ($file, $vers, $msg) = @_;
     $file ||= 'META.yml';
 
     unless($msg) {
@@ -129,7 +129,7 @@ sub meta_spec_ok {
         $msg .= " ($vers)"   if($vers);
     }
 
-    my ($yaml) = eval { Parse::CPAN::Meta::LoadFile($file) };
+    my ($data) = eval { Parse::CPAN::Meta::LoadFile($file) };
 
     if($@) {
         $Test->ok(0,"$file contains valid YAML");
@@ -142,7 +142,7 @@ sub meta_spec_ok {
 
     my %hash;
     $hash{spec} = $vers if($vers);
-    $hash{yaml} = $yaml;
+    $hash{data} = $data;
 
     my $spec = Test::CPAN::Meta::Version->new(%hash);
     if(my $result = $spec->parse()) {
@@ -152,7 +152,7 @@ sub meta_spec_ok {
         $Test->ok(1,$msg);
     }
 
-    return $yaml;
+    return $data;
 }
 
 q( Currently Listening To: Nine Inch Nails - "Head Down" from 'The Slip');
@@ -170,14 +170,14 @@ There are currently 3 distributions to test META files:
   Test-CPAN-Meta-YAML
 
 All three have slightly different requirements and are intended to be used in
-slightly different environments. 
+slightly different environments.
 
-Test-CPAN-Meta-YAML requires a YAML parser, and currently looks for the YAML or 
+Test-CPAN-Meta-YAML requires a YAML parser, and currently looks for the YAML or
 YAML::Syck modules. This is the original variant of the 3 and was intended to
 provide a more complete YAML validation of a META.yml.
 
 Test-CPAN-Meta requires the Parse::CPAN::Meta module, which is now part of Perl
-Core as of perl-5.10.1. This version is intended to be used by those only 
+Core as of perl-5.10.1. This version is intended to be used by those only
 wishing to rely on core modules to test their META.yml files.
 
 Test-CPAN-Meta-JSON is the most recent addition to the family, and is specifically
